.. _meeting:

=========================
Weekly Kolla team meeting
=========================

Meeting time: Wednesdays at 14:00 UTC in #openstack-kolla (`OFTC`_).

More info on how to join: https://meetings.opendev.org/#Kolla_Team_Meeting

We track CI, release, and feature status in the `whiteboard`_.

.. _meeting-agenda:

Agenda
======

The regular agenda for the weekly meeting is as follows::

    * Roll-call
    * Agenda
    * Announcements
    * Review action items from the last meeting
    * CI status
    * Release tasks
    * Regular stable releases (first meeting in a month)
    * Current cycle planning
    * Additional agenda (from whiteboard)
    * Open discussion

Anyone who would like to discuss an additional topic may post it on the
`whiteboard`_ under "Weekly meetings additional agenda".

Chairing a meeting
==================

Copy/Paste into IRC to kick the meeting off::

    #startmeeting kolla

Then, once the bot has caught up and everyone is settled::

    #topic rollcall

Once folks have checked in, run the agenda by the group present::

    #topic agenda
    copy and paste agenda from above

Go through topics from agenda::

    #topic something

And in the end finish the meeting::

    #endmeeting

Copy/Paste for IRC::

    https://bugs.launchpad.net/kolla
    #link https://bugs.launchpad.net/kolla

Previous meetings
=================

`IRC logs <http://meetings.opendev.org/meetings/kolla>`_

.. _whiteboard: https://etherpad.opendev.org/p/KollaWhiteBoard
.. _OFTC: https://www.oftc.net
